<?php

namespace Pinpoint\RedirectManager\App\Router;

/**
 * Class NoRouteHandler
 * @package Pinpoint\RedirectManager\App\Router
 */
class NoRouteHandler implements \Magento\Framework\App\Router\NoRouteHandlerInterface
{
    /**
     * @var \Pinpoint\RedirectManager\Model\NotFound
     */
    protected $notFound;

    /**
     * @var \Pinpoint\RedirectManager\Model\Redirect
     */
    protected $redirect;

    /**
     * @var array
     */
    protected $filters = ['app/etc', '/pub/media', '/media/', '/favicon.ico'];

    /**
     * NoRouteHandler constructor.
     * @param \Pinpoint\RedirectManager\Model\NotFound $notFound
     * @param \Pinpoint\RedirectManager\Model\Redirect $redirect
     */
    public function __construct(
        \Pinpoint\RedirectManager\Model\NotFound $notFound,
        \Pinpoint\RedirectManager\Model\Redirect $redirect
    ) {
        $this->notFound = $notFound;
        $this->redirect = $redirect;
    }

    /**
     * @param \Magento\Framework\App\RequestInterface $request
     * @return bool
     */
    public function process(\Magento\Framework\App\RequestInterface $request)
    {
        foreach ($this->filters as $filter) {
            if (strpos($request->getPathInfo(), $filter) !== false) {
                $request->setModuleName('cms')->setControllerName('noroute')->setActionName('index');
                return false;
            }
        }

        //log 404 to db table
        $this->notFound->log($request);

        if ($redirect = $this->redirect->hasRedirect($request)) {
            header(
                'Location: ' . $redirect->getData('target_path'),
                true,
                (int) $redirect->getData('redirect_type')
            );
            exit;
        }

        $request->setModuleName('cms')->setControllerName('noroute')->setActionName('index');
        return false;
    }

}