<?php
namespace Pinpoint\RedirectManager\Controller\Adminhtml\Redirects;

use Magento\Backend\App\Action;
use Pinpoint\RedirectManager\Model\Page;
use Magento\Framework\App\Request\DataPersistorInterface;
use Magento\Framework\Exception\LocalizedException;

/**
 * Class Save
 * @package Pinpoint\RedirectManager\Controller\Adminhtml\Redirects
 */
class Save extends \Magento\Backend\App\Action
{
    /**
     * Authorization level of a basic admin session
     *
     * @see _isAllowed()
     */
    const ADMIN_RESOURCE = 'Pinpoint_RedirectManager::redirectAdd';

    /**
     * @var DataPersistorInterface
     */
    protected $dataPersistor;

    /**
     * @var \Pinpoint\RedirectManager\Model\Redirect
     */
    protected $redirect;

    /**
     * @param Action\Context $context
     * @param DataPersistorInterface $dataPersistor
     */
    public function __construct(
        Action\Context $context,
        DataPersistorInterface $dataPersistor,
        \Pinpoint\RedirectManager\Model\Redirect $redirect
    ) {
        $this->dataPersistor = $dataPersistor;
        $this->redirect = $redirect;
        parent::__construct($context);
    }

    /**
     * Save action
     *
     * @SuppressWarnings(PHPMD.CyclomaticComplexity)
     * @return \Magento\Framework\Controller\ResultInterface
     */
    public function execute()
    {
        $data = $this->getRequest()->getPostValue();

        /** @var \Magento\Backend\Model\View\Result\Redirect $resultRedirect */
        $resultRedirect = $this->resultRedirectFactory->create();
        if ($data) {
            if (empty($data['id'])) {
                $data['id'] = null;
            }

            /** @var \Pinpoint\RedirectManager\Model\Redirect $model */
            $model = $this->redirect;

            $id = $this->getRequest()->getParam('id');
            if ($id) {
                $model->load($id);
            }

            $model->setData($data);

            try {
                $model->save();
                $this->messageManager->addSuccess(__('The redirect has been saved.'));
                $this->dataPersistor->clear('pinpoint_redirectmanager_resourcemodel_redirect_collection');
                if ($this->getRequest()->getParam('back')) {
                    return $resultRedirect->setPath('*/*/new', ['id' => $model->getId(), '_current' => true]);
                }
                return $resultRedirect->setPath('*/*/');
            } catch (LocalizedException $e) {
                $this->messageManager->addError($e->getMessage());
            } catch (\Exception $e) {
                $this->messageManager->addException($e, __('Something went wrong while saving the data.'));
            }

            $this->dataPersistor->set('pinpoint_redirectmanager_resourcemodel_redirect_collection', $data);
            return $resultRedirect->setPath('*/*/new', ['id' => $this->getRequest()->getParam('id')]);
        }
        return $resultRedirect->setPath('*/*/');
    }    
}
